@@ -13,14 +13,9 @@
 import os
 import time
 
-from cinderclient.v3 import client as cinderclient
 import fixtures
-from keystoneauth1.exceptions import discovery as discovery_exc
 from keystoneauth1 import identity
 from keystoneauth1 import session as ksession
-from keystoneclient import client as keystoneclient
-from keystoneclient import discover as keystone_discover
-from neutronclient.v2_0 import client as neutronclient
 import openstack.config
 import openstack.config.exceptions
 import openstack.connection
@@ -39,18 +34,6 @@ BOOT_IS_COMPLETE = ("login as 'cirros' user. default password: "
                     "'gocubsgo'. use 'sudo' for root.")
 
 
-def is_keystone_version_available(session, version):
-    """Given a (major, minor) pair, check if the API version is enabled."""
-
-    d = keystone_discover.Discover(session)
-    try:
-        d.create_client(version)
-    except (discovery_exc.DiscoveryFailure, discovery_exc.VersionNotAvailable):
-        return False
-    else:
-        return True
-
-
 # The following are simple filter functions that filter our available
 # image / flavor list so that they can be used in standard testing.
 def pick_flavor(flavors):
@@ -235,8 +218,7 @@ class ClientTestBase(testtools.TestCase):
 
         if "network" not in CACHE:
             # Get the networks from neutron.
-            neutron = neutronclient.Client(session=session)
-            neutron_networks = neutron.list_networks()['networks']
+            neutron_networks = self.openstack.network.networks()
             # Convert the neutron dicts to Network objects.
             nets = []
             for network in neutron_networks:
@@ -268,11 +250,6 @@ class ClientTestBase(testtools.TestCase):
             cli_dir=cli_dir,
             insecure=self.insecure)
 
-        self.keystone = keystoneclient.Client(session=session,
-                                              username=user,
-                                              password=passwd)
-        self.cinder = cinderclient.Client(auth=auth, session=session)
-
     def _get_novaclient(self, session):
         nc = novaclient.client.Client("2", session=session)
 
@@ -332,7 +309,7 @@ class ClientTestBase(testtools.TestCase):
         """
         start_time = time.time()
         while time.time() - start_time < timeout:
-            volume = self.cinder.volumes.get(volume.id)
+            volume = self.openstack.block_storage.get_volume(volume)
             if volume.status == status:
                 break
             time.sleep(poll_interval)
@@ -507,11 +484,9 @@ class ClientTestBase(testtools.TestCase):
 
     def _get_project_id(self, name):
         """Obtain project id by project name."""
-        if self.keystone.version == "v3":
-            project = self.keystone.projects.find(name=name)
-        else:
-            project = self.keystone.tenants.find(name=name)
-        return project.id
+        return self.openstack.identity.find_project(
+            name, ignore_missing=False
+        ).id
 
     def _cleanup_server(self, server_id):
         """Deletes a server and waits for it to be gone."""
@@ -550,41 +525,39 @@ class ClientTestBase(testtools.TestCase):
         self.fail('Unable to find alternate for flavor: %s' % flavor_name)
 
 
-class TenantTestBase(ClientTestBase):
-    """Base test class for additional tenant and user creation which
+class ProjectTestBase(ClientTestBase):
+    """Base test class for additional project and user creation which
     could be required in various test scenarios
     """
 
     def setUp(self):
-        super(TenantTestBase, self).setUp()
+        super(ProjectTestBase, self).setUp()
         user_name = uuidutils.generate_uuid()
         project_name = uuidutils.generate_uuid()
         password = 'password'
 
-        if self.keystone.version == "v3":
-            project = self.keystone.projects.create(project_name,
-                                                    self.project_domain_id)
-            self.project_id = project.id
-            self.addCleanup(self.keystone.projects.delete, self.project_id)
+        project = self.openstack.identity.create_project(
+            name=project_name,
+            domain_id=self.project_domain_id)
+        self.project_id = project.id
+        self.addCleanup(
+            self.openstack.identity.delete_project, self.project_id)
 
-            self.user_id = self.keystone.users.create(
-                name=user_name, password=password,
-                default_project=self.project_id).id
+        self.user_id = self.openstack.identity.create_user(
+            name=user_name, password=password,
+            default_project=self.project_id).id
 
-            for role in self.keystone.roles.list():
-                if "member" in role.name.lower():
-                    self.keystone.roles.grant(role.id, user=self.user_id,
-                                              project=self.project_id)
-                    break
-        else:
-            project = self.keystone.tenants.create(project_name)
-            self.project_id = project.id
-            self.addCleanup(self.keystone.tenants.delete, self.project_id)
+        for role in self.openstack.identity.roles():
+            if "member" in role.name.lower():
+                self.openstack.identity.assign_project_role_to_user(
+                    project=self.project_id,
+                    user=self.user_id,
+                    role=role.id)
+                break
 
-            self.user_id = self.keystone.users.create(
-                user_name, password, tenant_id=self.project_id).id
+        self.addCleanup(
+            self.openstack.identity.delete_user, self.user_id)
 
-        self.addCleanup(self.keystone.users.delete, self.user_id)
         self.cli_clients_2 = tempest.lib.cli.base.CLIClient(
             username=user_name,
             password=password,
